#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 libBF
version:              0.6.7
visibility:           public
id:                   libBF-0.6.7-8mkBTwEp066JBIaam08ksF
key:                  libBF-0.6.7-8mkBTwEp066JBIaam08ksF
license:              MIT
maintainer:           iavor.diatchki@gmail.com
author:               Iavor Diatchki
synopsis:             A binding to the libBF library.
description:
    LibBF is a C library for working with arbitray precision
    IEEE 754 floating point numbers.

category:             Data
abi:                  5d86bd5d120a78267ada84ad6ae3d995
exposed:              True
exposed-modules:      LibBF LibBF.Mutable LibBF.Opts
import-dirs:          /usr/lib/ghc-9.6.6/site-local/libBF-0.6.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/libBF-0.6.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/libBF-0.6.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-libbf
hs-libraries:         HSlibBF-0.6.7-8mkBTwEp066JBIaam08ksF
extra-libraries:      bf
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    hashable-1.4.7.0-4qZi9v5WFMZ3p1WVFpevAr

haddock-interfaces:   /usr/share/doc/haskell-libbf/html/libBF.haddock
haddock-html:         /usr/share/doc/haskell-libbf/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

